@@ -2,16 +2,16 @@ package WWW::Finger::BitworkingFingerProtocol;
 
 use 5.008;
 use base qw(WWW::Finger);
-use strict;
+use common::sense;
 
 use Carp;
 use JSON;
 use LWP::UserAgent;
-use WWW::Finger;
 use URI;
 use URI::Escape;
+use WWW::Finger;
 
-our $VERSION = '0.09';
+our $VERSION = '0.100';
 
 BEGIN
 {
